from ...common import (WEAKNESS_BEFORE_STOP_WORDS, WEAKNESS_PATTERN, CONFIGURATION_PATTERN, ATTACKER_PATTERN,
                       ATTACKER_BEFORE_STOP_WORDS, IMPACT_PATTERN, IMPACT_BEFORE_STOP_WORDS, VECTOR_PATTERN,
                       VECTOR_BEFORE_STOP_WORDS, ROOT_CAUSE_PATTERN, ROOT_CAUSE_BEFORE_STOP_WORD)

CONFIG_WEAKNESS_ATTACKER_PATTERN = (CONFIGURATION_PATTERN + WEAKNESS_BEFORE_STOP_WORDS + WEAKNESS_PATTERN +
                                    ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN)


# configuration weakness attacker impact vector root_cause
DETAILS_6_1 = (CONFIG_WEAKNESS_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$')

# configuration weakness attacker impact vector
DETAILS_5_1 = (CONFIG_WEAKNESS_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + r'\.$')

# configuration weakness attacker impact
DETAILS_4_1 = CONFIG_WEAKNESS_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.$'


CONFIG_WEAKNESS_ATTACKER_PATTERNS = {
    '6_1': DETAILS_6_1,
    '5_1': DETAILS_5_1,
    '4_1': DETAILS_4_1
}



from ...common import (WEAKNESS_PATTERN, WEAKNESS_AFTER_STOP_WORDS, CONFIGURATION_PATTERN, VECTOR_BEFORE_STOP_WORDS,
                       CONFIGURATION_BEFORE_STOP_WORDS, COMPONENT_PATTERN, COMPONENT_BEFORE_STOP_WORDS,
                       ATTACKER_PATTERN, ATTACKER_BEFORE_STOP_WORDS, IMPACT_PATTERN, IMPACT_BEFORE_STOP_WORDS,
                       VECTOR_PATTERN, ATTACKER_AFTER_STOP_WORDS, ROOT_CAUSE_BEFORE_STOP_WORD, ROOT_CAUSE_PATTERN,
                       CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN, CONFIGURATION_AFTER_STOP_WORDS)

# weakness component configuration
WEAKNESS_COMP_CONFIG_PATTERN = (r'(An |A |)' + WEAKNESS_PATTERN + WEAKNESS_AFTER_STOP_WORDS +
                                COMPONENT_BEFORE_STOP_WORDS + COMPONENT_PATTERN + CONFIGURATION_BEFORE_STOP_WORDS +
                                CONFIGURATION_PATTERN + CONFIGURATION_AFTER_STOP_WORDS)

# weakness component configuration condition attacker impact vector
DETAILS_7_1 = (WEAKNESS_COMP_CONFIG_PATTERN + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN +
               ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN + ATTACKER_AFTER_STOP_WORDS + IMPACT_BEFORE_STOP_WORDS +
               IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS + VECTOR_PATTERN + r'\.')

# weakness component configuration attacker impact vector
DETAILS_6_1 = (WEAKNESS_COMP_CONFIG_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               ATTACKER_AFTER_STOP_WORDS + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + r'\.')

# weakness component configuration attacker impact root_cause
DETAILS_6_2 = (WEAKNESS_COMP_CONFIG_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               ATTACKER_AFTER_STOP_WORDS + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD +
               ROOT_CAUSE_PATTERN + r'\.$')

# weakness component configuration attacker impact root_cause
DETAILS_6_3 = (WEAKNESS_COMP_CONFIG_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS +
               IMPACT_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$')

# weakness component configuration attacker impact condition
DETAILS_6_4 = (WEAKNESS_COMP_CONFIG_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               ATTACKER_AFTER_STOP_WORDS + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + CONDITION_BEFORE_STOP_WORDS +
               CONDITION_PATTERN + r'\.$')

# weakness component configuration attacker impact
DETAILS_5_1 = (WEAKNESS_COMP_CONFIG_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS +
               IMPACT_PATTERN + r'\.')

# weakness component configuration root_cause
DETAILS_4_1 = WEAKNESS_COMP_CONFIG_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$'

# weakness component configuration impact
DETAILS_4_2 = WEAKNESS_COMP_CONFIG_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.'

# weakness component configuration
DETAILS_3_1 = WEAKNESS_COMP_CONFIG_PATTERN + r'\.$'

WEAKNESS_COMP_CONFIG_PATTERNS = {
    '7_1': DETAILS_7_1,
    '6_1': DETAILS_6_1,
    '6_2': DETAILS_6_2,
    '6_3': DETAILS_6_3,
    '6_4': DETAILS_6_4,
    '5_1': DETAILS_5_1,
    '4_1': DETAILS_4_1,
    '4_2': DETAILS_4_2,
    '3_1': DETAILS_3_1
}



from ...common import (WEAKNESS_PATTERN, WEAKNESS_AFTER_STOP_WORDS, CONFIGURATION_PATTERN, VECTOR_BEFORE_STOP_WORDS,
                       CONFIGURATION_BEFORE_STOP_WORDS, COMPONENT_PATTERN, COMPONENT_BEFORE_STOP_WORDS,
                       ATTACKER_PATTERN, ATTACKER_BEFORE_STOP_WORDS, IMPACT_PATTERN, IMPACT_BEFORE_STOP_WORDS,
                       VECTOR_PATTERN, ATTACKER_AFTER_STOP_WORDS, ROOT_CAUSE_BEFORE_STOP_WORD, ROOT_CAUSE_PATTERN,
                       CONFIGURATION_AFTER_STOP_WORDS, CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN)


WEAKNESS_CONFIG_ATTACKER_PATTERN = (r'(An |A |)' + WEAKNESS_PATTERN + WEAKNESS_AFTER_STOP_WORDS +
                                    CONFIGURATION_BEFORE_STOP_WORDS + CONFIGURATION_PATTERN +
                                    CONFIGURATION_AFTER_STOP_WORDS + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
                                    ATTACKER_AFTER_STOP_WORDS)

# weakness configuration attacker impact vector component
DETAILS_6_1 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + COMPONENT_BEFORE_STOP_WORDS + COMPONENT_PATTERN + r'\.')

# weakness configuration attacker impact vector root_cause
DETAILS_6_2 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$')

# weakness configuration attacker impact vector condition
DETAILS_6_3 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN + r'\.$')

# weakness configuration attacker impact vector
DETAILS_5_1 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS +
               VECTOR_PATTERN + r'\.$')

# weakness configuration attacker impact component
DETAILS_5_2 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN +
               COMPONENT_BEFORE_STOP_WORDS + COMPONENT_PATTERN + r'\.$')

# weakness configuration attacker impact root_cause
DETAILS_5_3 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN +
               ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$')

# weakness configuration attacker impact condition
DETAILS_5_4 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN +
               CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN + r'\.$')

# weakness configuration attacker impact
DETAILS_4_1 = (WEAKNESS_CONFIG_ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.')

WEAKNESS_CONFIG_ATTACKER_PATTERNS = {
    '6_1': DETAILS_6_1,
    '6_2': DETAILS_6_2,
    '6_3': DETAILS_6_3,
    '5_1': DETAILS_5_1,
    '5_2': DETAILS_5_2,
    '5_3': DETAILS_5_3,
    '5_4': DETAILS_5_4,
    '4_1': DETAILS_4_1
}



from ...common import (WEAKNESS_BEFORE_STOP_WORDS, WEAKNESS_PATTERN, CONFIGURATION_PATTERN, IMPACT_PATTERN,
                       IMPACT_BEFORE_STOP_WORDS, CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN)

CONFIG_WEAKNESS_CONDITION_PATTERN = (CONFIGURATION_PATTERN + WEAKNESS_BEFORE_STOP_WORDS + WEAKNESS_PATTERN +
                                     CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN)


# configuration weakness condition impact
DETAILS_4_1 = CONFIG_WEAKNESS_CONDITION_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.$'


CONFIG_WEAKNESS_CONDITION_PATTERNS = {
    '4_1': DETAILS_4_1,
}



from ...common import (CONFIGURATION_PATTERN, ATTACKER_PATTERN, ATTACKER_BEFORE_STOP_WORDS, ROOT_CAUSE_PATTERN,
                       ROOT_CAUSE_BEFORE_STOP_WORD, CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN,
                       IMPACT_BEFORE_STOP_WORDS, IMPACT_PATTERN, VECTOR_BEFORE_STOP_WORDS, VECTOR_PATTERN)


# configuration condition root_cause
CONFIG_CONDITION_CAUSE_PATTERN = (
        r'(?:The |)' + CONFIGURATION_PATTERN + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN +
        ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN
)


# configuration condition root_cause attacker impact vector
DETAILS_5_1 = (
        CONFIG_CONDITION_CAUSE_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN + IMPACT_BEFORE_STOP_WORDS +
        IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS + VECTOR_PATTERN + r'\.$'
)


CONFIG_CONDITION_CAUSE_PATTERNS = {
    '5_1': DETAILS_5_1
}



from ...common import (CONFIGURATION_PATTERN, ROOT_CAUSE_PATTERN, ROOT_CAUSE_BEFORE_STOP_WORD,
                       CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN, IMPACT_BEFORE_STOP_WORDS, IMPACT_PATTERN)


# configuration root_cause condition
CONFIG_CAUSE_CONDITION_PATTERN = (r'(?:The |)' + CONFIGURATION_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD +
                                 ROOT_CAUSE_PATTERN + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN)


# configuration root_cause condition impact
DETAILS_4_1 = CONFIG_CAUSE_CONDITION_PATTERN + IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + r'\.$'


CONFIG_CAUSE_CONDITION_PATTERNS = {
    '4_1': DETAILS_4_1
}



from ...common import (WEAKNESS_PATTERN, WEAKNESS_AFTER_STOP_WORDS, CONFIGURATION_PATTERN, VECTOR_BEFORE_STOP_WORDS,
                       CONFIGURATION_BEFORE_STOP_WORDS, VECTOR_PATTERN, ATTACKER_BEFORE_STOP_WORDS, ATTACKER_PATTERN,
                       IMPACT_BEFORE_STOP_WORDS, IMPACT_PATTERN, CONDITION_BEFORE_STOP_WORDS, CONDITION_PATTERN,
                       CONFIGURATION_AFTER_STOP_WORDS, ROOT_CAUSE_BEFORE_STOP_WORD, ROOT_CAUSE_PATTERN)

# weakness configuration condition
WEAKNESS_CONFIG_CONDITION_PATTERN =  (r'(An |A |)' + WEAKNESS_PATTERN + WEAKNESS_AFTER_STOP_WORDS +
                                      CONFIGURATION_BEFORE_STOP_WORDS + CONFIGURATION_PATTERN +
                                      CONFIGURATION_AFTER_STOP_WORDS + CONDITION_BEFORE_STOP_WORDS + CONDITION_PATTERN)

# weakness configuration condition attacker impact vector root_cause
DETAILS_7_1 = (WEAKNESS_CONFIG_CONDITION_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS + VECTOR_PATTERN +
               ROOT_CAUSE_BEFORE_STOP_WORD + ROOT_CAUSE_PATTERN + r'\.$')


# weakness configuration condition attacker impact vector
DETAILS_6_1 = (WEAKNESS_CONFIG_CONDITION_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               IMPACT_BEFORE_STOP_WORDS + IMPACT_PATTERN + VECTOR_BEFORE_STOP_WORDS + VECTOR_PATTERN + r'\.$')


WEAKNESS_CONFIG_CONDITION_PATTERNS = {
    '7_1': DETAILS_7_1,
    '6_1': DETAILS_6_1,
}



from ...common import (CONFIGURATION_PATTERN, ATTACKER_PATTERN, ATTACKER_BEFORE_STOP_WORDS, ROOT_CAUSE_PATTERN,
                       ROOT_CAUSE_BEFORE_STOP_WORD, ATTACKER_AFTER_STOP_WORDS, WEAKNESS_BEFORE_STOP_WORDS,
                       WEAKNESS_PATTERN, WEAKNESS_AFTER_STOP_WORDS)


# configuration root_cause
CONFIG_CAUSE_WEAKNESS_PATTERN = (r'(?:The |)' + CONFIGURATION_PATTERN + ROOT_CAUSE_BEFORE_STOP_WORD +
                                 ROOT_CAUSE_PATTERN + WEAKNESS_BEFORE_STOP_WORDS + WEAKNESS_PATTERN +
                                 WEAKNESS_AFTER_STOP_WORDS)


# configuration root_cause weakness attacker
DETAILS_4_1 = (CONFIG_CAUSE_WEAKNESS_PATTERN + ATTACKER_BEFORE_STOP_WORDS + ATTACKER_PATTERN +
               ATTACKER_AFTER_STOP_WORDS + r'\.$')


CONFIG_CAUSE_WEAKNESS_PATTERNS = {
    '4_1': DETAILS_4_1
}



import json

from cve_driller.driller import CVEDriller


if __name__ == "__main__":
    driller = CVEDriller(verbose=True)
    cve_id = "CVE-2018-7187"

    input_path = f"data/inputs/CWE-78/comp_config_condition/{cve_id}.txt"
    #description = open(input_path, 'r').read()
    description = "The Edit Comments WordPress plugin through 0.3 does not sanitise, validate or escape the jal_edit_comments GET parameter before using it in a SQL statement, leading to a SQL injection issue"
    detail_type, details = driller(description)
    # CVE-2021-24551

    if details:
        print(json.dumps(details, indent=4))

    #if details:
    #    output_path = f"data/outputs/{detail_type.value}/{cve_id}.json"

    #    with open(output_path, 'w') as f:
    #        json.dump(details, f, indent=4)
